import { PlatformAccessory } from "homebridge";
import { ProtectCameraChannelConfig, ProtectCameraConfig, ProtectEventPacket } from "unifi-protect";
import { ProtectDevice } from "./protect-device.js";
import { ProtectNvr } from "./protect-nvr.js";
import { ProtectStreamingDelegate } from "./protect-stream.js";
export interface RtspEntry {
    channel: ProtectCameraChannelConfig;
    name: string;
    resolution: [number, number, number];
    url: string;
}
export declare class ProtectCamera extends ProtectDevice {
    hasHksv: boolean;
    hasHwAccel: boolean;
    private isDeleted;
    private isDoorbellConfigured;
    isRinging: boolean;
    private isVideoConfigured;
    packageCamera: ProtectPackageCamera | null;
    private rtspEntries;
    private rtspQuality;
    snapshotUrl: string;
    stream: ProtectStreamingDelegate;
    ufp: ProtectCameraConfig;
    constructor(nvr: ProtectNvr, device: ProtectCameraConfig, accessory: PlatformAccessory);
    protected configureHints(): boolean;
    protected configureDevice(): Promise<boolean>;
    cleanup(): void;
    protected eventHandler(packet: ProtectEventPacket): void;
    private smartMotionEventHandler;
    private configureMotionSmartSensor;
    private configureDoorbellTrigger;
    protected configureVideoDoorbell(): boolean;
    private configureCameraDetails;
    private configureVideoStream;
    protected configureSnapshotUpdates(): Promise<boolean>;
    private configurePackageCamera;
    private configureHksv;
    private configureHksvRecordingSwitch;
    private configureDynamicBitrateSwitch;
    private configureNvrRecordingSwitch;
    protected configureMqtt(): boolean;
    updateDevice(): boolean;
    getBitrate(channelId: number): number;
    setBitrate(channelId: number, value: number): Promise<boolean>;
    private findRtspEntry;
    findRtsp(width: number, height: number, camera?: ProtectCameraConfig | null, address?: string, rtspEntries?: RtspEntry[]): RtspEntry | null;
    findRecordingRtsp(width: number, height: number, camera?: ProtectCameraConfig | null, rtspEntries?: RtspEntry[]): RtspEntry | null;
    private sortByResolutions;
    private getResolution;
}
export declare class ProtectPackageCamera extends ProtectCamera {
    protected configureDevice(): Promise<boolean>;
    findRtsp(): RtspEntry | null;
    getBitrate(channelId: number): number;
    setBitrate(): Promise<boolean>;
}
