import { API, HAP, PlatformAccessory } from "homebridge";
import { ProtectApi, ProtectEventPacket } from "unifi-protect";
import { ProtectDeviceConfigTypes, ProtectLogging } from "./protect-types.js";
import { ProtectNvr } from "./protect-nvr.js";
import { ProtectNvrConfig } from "unifi-protect";
import { ProtectPlatform } from "./protect-platform.js";
export interface ProtectHints {
    hardwareTranscoding: boolean;
    ledStatus: boolean;
    logDoorbell: boolean;
    logHksv: boolean;
    logMotion: boolean;
    probesize: number;
    timeshift: boolean;
    transcode: boolean;
    transcodeHighLatency: boolean;
    twoWayAudio: boolean;
}
export declare abstract class ProtectBase {
    readonly api: API;
    private debug;
    protected readonly hap: HAP;
    readonly log: ProtectLogging;
    readonly nvr: ProtectNvr;
    ufpApi: ProtectApi;
    readonly platform: ProtectPlatform;
    constructor(nvr: ProtectNvr);
    protected setInfo(accessory: PlatformAccessory, device: ProtectDeviceConfigTypes | ProtectNvrConfig): boolean;
    get name(): string;
}
export declare abstract class ProtectDevice extends ProtectBase {
    accessory: PlatformAccessory;
    hints: ProtectHints;
    protected listeners: {
        [index: string]: (packet: ProtectEventPacket) => void;
    };
    abstract ufp: ProtectDeviceConfigTypes;
    constructor(nvr: ProtectNvr, accessory: PlatformAccessory);
    protected configureHints(): boolean;
    protected configureInfo(): boolean;
    cleanup(): void;
    protected configureMotionSensor(isEnabled?: boolean, isInitialized?: boolean): boolean;
    private configureMotionSwitch;
    private configureMotionTrigger;
    private configureMqttMotionTrigger;
    isOptionEnabled(option: string, defaultReturnValue?: boolean, address?: string, addressOnly?: boolean): boolean;
    isReservedName(name: string | undefined): boolean;
    get name(): string;
}
