/// <reference types="node" />
import { CameraController, CameraStreamingDelegate, H264Level, H264Profile, PrepareStreamCallback, PrepareStreamRequest, SnapshotRequest, SnapshotRequestCallback, StreamRequestCallback, StreamingRequest } from "homebridge";
import { ProtectCamera, ProtectPackageCamera } from "./protect-camera.js";
import { ProtectLogging } from "./protect-types.js";
import { ProtectPlatform } from "./protect-platform.js";
import { ProtectRecordingDelegate } from "./protect-record.js";
export declare class ProtectStreamingDelegate implements CameraStreamingDelegate {
    private readonly api;
    private readonly config;
    controller: CameraController;
    private readonly hap;
    hksv: ProtectRecordingDelegate | null;
    readonly log: ProtectLogging;
    private readonly nvr;
    private ongoingSessions;
    private pendingSessions;
    readonly platform: ProtectPlatform;
    readonly protectCamera: ProtectCamera | ProtectPackageCamera;
    private probesizeOverride;
    private probesizeOverrideCount;
    private probesizeOverrideTimeout?;
    private rtspEntry;
    private savedBitrate;
    private snapshotCache;
    verboseFfmpeg: boolean;
    readonly videoEncoderOptions: string[];
    constructor(protectCamera: ProtectCamera, resolutions: [number, number, number][]);
    handleSnapshotRequest(request?: SnapshotRequest, callback?: SnapshotRequestCallback): Promise<void>;
    prepareStream(request: PrepareStreamRequest, callback: PrepareStreamCallback): Promise<void>;
    private startStream;
    handleStreamRequest(request: StreamingRequest, callback: StreamRequestCallback): Promise<void>;
    private getCachedSnapshot;
    getSnapshot(request?: SnapshotRequest, isLoggingErrors?: boolean): Promise<Buffer | null>;
    stopStream(sessionId: string): Promise<void>;
    shutdown(): Promise<void>;
    adjustProbeSize(): void;
    getH264Level(level: H264Level): string;
    getH264Profile(profile: H264Profile): string;
    private getVideoEncoderOptions;
}
